<?php

/**
 * @file
 * FVL configuration file.
 */

/**
 * Callback for the admin configuration page.
 */
function fvl_admin_settings($form, &$form_state) {
  $types = node_type_get_names();

  $form['fvl_showlink_always'] = array(
    '#type' => 'checkbox',
    '#title' => t('Always display a "show" link'),
    '#description' => t('Display a "show" link even if user does not have access to view data of the field'),
    '#default_value' => variable_get('fvl_not_available_text', '') == '' ? FALSE : TRUE,
  );
  $form['fvl_not_available_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Text to replace'),
    '#description' => t('The text to be displayed if access to data of the field is not available'),
    '#default_value' => variable_get('fvl_not_available_text', ''),
    '#states' => array(
      'invisible' => array(
        ':input[name="fvl_showlink_always"]' => array('checked' => FALSE),
      ),
    ),
  );

  $form['fields'] = array(
    '#type' => 'container',
    '#prefix' => '<h3>' . t('Select fields for each of content types  that should be handled module:') . '</h3>',
  );
  // Creating list of fields for each type of nodes having a field(s).
  foreach ($types as $type => $label) {
    $fields = field_info_instances('node', $type);
    if ($fields) {
      $form['fields'][$type] = array(
        '#type' => 'fieldset',
        '#title' => t('Type: @type', array('@type' => $label)),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
      );
      $field_list = array();
      foreach ($fields as $field => $data) {
        $field_list[$field] = $data['label'] . ' (' . $field . ')';
      }
      $form['fields'][$type]['fvl_type_' . $type] = array(
        '#type' => 'checkboxes',
        '#options' => $field_list,
        '#default_value' => variable_get('fvl_type_' . $type, array()),
      );
    }
  }

  $form['array_filter'] = array(
    '#type' => 'value',
    '#value' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * Configuration form submit.
 */
function fvl_admin_settings_submit($form, &$form_state) {
  if (!$form_state['values']['fvl_showlink_always']) {
    $form_state['values']['fvl_not_available_text'] = '';
  }
  $permissions_page = url('admin/people/permissions', array('fragment' => 'module-fvl'));
  drupal_set_message(t('Now don\'t forget to set the access rights for selected fields on <a href="!permissions_page">permissions page</a>.', array('!permissions_page' => $permissions_page)));

  system_settings_form_submit($form, $form_state);
}
